==============================================
``psyclone.psyir.transformations.hoist_trans``
==============================================

.. automodule:: psyclone.psyir.transformations.hoist_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.transformations.hoist_trans


Classes
=======

- :py:class:`HoistTrans`:
  This transformation takes an assignment and moves it outside of


.. autoclass:: HoistTrans
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: HoistTrans
      :parts: 1
